@@ -65,7 +65,7 @@ sip_init(int limit, int only_calls, int no_incomplete)
     // Initialize calls lock
     pthread_mutexattr_t attr;
     pthread_mutexattr_init(&attr);
-#if defined(PTHREAD_MUTEX_RECURSIVE) || defined(__FreeBSD__)
+#if defined(PTHREAD_MUTEX_RECURSIVE) || defined(__FreeBSD__) || defined(BSD) || defined (__OpenBSD__)
     pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
 #else
     pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE_NP);
@@ -74,14 +74,15 @@ sip_init(int limit, int only_calls, int no_incomplete)
 
     // Initialize payload parsing regexp
     match_flags = REG_EXTENDED | REG_ICASE | REG_NEWLINE;
-    regcomp(&calls.reg_callid, "^(Call-ID|i): (.+)\r$", match_flags);
-    regcomp(&calls.reg_xcallid, "^(X-Call-ID|X-CID): (.+)\r$", match_flags);
-    regcomp(&calls.reg_response, "^SIP/2.0 (([0-9]{3}) .+)\r$", match_flags);
-    regcomp(&calls.reg_cseq, "CSeq: ([0-9]+) (.+)\r$", match_flags);
-    regcomp(&calls.reg_from, "(From|f): [^:]*:(([^@]+)@?[^\r>;]+)", match_flags);
-    regcomp(&calls.reg_to, "(To|t): [^:]*:(([^@]+)@?[^\r>;]+)", match_flags);
-    regcomp(&calls.reg_sdp_addr, "^c=[^[:space:]]+ [^[:space:]]+ (.+)\r$", match_flags);
-    regcomp(&calls.reg_sdp_port, "^m=[^[:space:]]+ ([0-9]+)", match_flags);
+    regcomp(&calls.reg_method, "^([a-zA-Z]+) sip:\\S+ SIP/2.0\r", match_flags & ~REG_NEWLINE);
+    regcomp(&calls.reg_callid, "^(Call-ID|i):\\s*(\\S+)\r$", match_flags);
+    regcomp(&calls.reg_xcallid, "^(X-Call-ID|X-CID):\\s*(\\S+)\r$", match_flags);
+    regcomp(&calls.reg_response, "^SIP/2.0\\s*(([0-9]{3}) [^\r]+)\r", match_flags & ~REG_NEWLINE);
+    regcomp(&calls.reg_cseq, "^CSeq:\\s*([0-9]+) .+\r$", match_flags);
+    regcomp(&calls.reg_from, "^(From|f):\\s*[^:]*:(([^@]+)@?[^\r>;]+)", match_flags);
+    regcomp(&calls.reg_to, "^(To|t):\\s*[^:]*:(([^@]+)@?[^\r>;]+)", match_flags);
+    regcomp(&calls.reg_sdp_addr, "^c=\\S+ \\S+ (.+)\r$", match_flags);
+    regcomp(&calls.reg_sdp_port, "^m=\\S+ ([0-9]+)", match_flags);
 
 }
 
@@ -234,6 +235,15 @@ sip_load_message(const struct pcap_pkthdr *header, const char *src, u_short spor
         return NULL;
     }
 
+    // Get Method and request for the following checks
+    // There is no need to parse all payload at this point
+    // If no response or request code is found, this is not a SIP message
+    if (!msg_get_reqresp(msg)) {
+        // Deallocate message memory
+        sip_msg_destroy(msg);
+        return NULL;
+    }
+
     // Store sorce address. Prefix too long IPv6 addresses with two dots
     if (strlen(src) > 15) {
         sprintf(msg->src, "..%s", src + strlen(src) - 13);
@@ -268,10 +278,6 @@ sip_load_message(const struct pcap_pkthdr *header, const char *src, u_short spor
             return NULL;
         }
 
-        // Get Method and request for the following checks
-        // There is no need to parse all payload at this point
-        msg_get_reqresp(msg);
-
         // User requested only INVITE starting dialogs
         if (calls.only_calls) {
             if (msg->reqresp != SIP_METHOD_INVITE) {
@@ -567,7 +573,7 @@ int
 msg_get_reqresp(sip_msg_t *msg)
 {
     regmatch_t pmatch[3];
-    char reqresp[20], cseq[11];
+    char reqresp[20];
     const char *payload = msg->payload;
 
     // If not already parsed
@@ -576,10 +582,8 @@ msg_get_reqresp(sip_msg_t *msg)
         memset(reqresp, 0, sizeof(reqresp));
 
         // Method & CSeq
-        if (regexec(&calls.reg_cseq, payload, 3, pmatch, 0) == 0) {
-            sprintf(cseq, "%.*s", pmatch[1].rm_eo - pmatch[1].rm_so, payload + pmatch[1].rm_so);
-            msg->cseq = atoi(cseq);
-            sprintf(reqresp, "%.*s", pmatch[2].rm_eo - pmatch[2].rm_so, payload + pmatch[2].rm_so);
+        if (regexec(&calls.reg_method, payload, 2, pmatch, 0) == 0) {
+            sprintf(reqresp, "%.*s", pmatch[1].rm_eo - pmatch[1].rm_so, payload + pmatch[1].rm_so);
             msg_set_attribute(msg, SIP_ATTR_METHOD, reqresp);
         }
 
@@ -600,7 +604,7 @@ int
 msg_parse_payload(sip_msg_t *msg, const char *payload)
 {
     regmatch_t pmatch[4];
-    char date[12], time[20];
+    char date[12], time[20], cseq[11];
 
     // If message has already been parsed, we've finished
     if (msg->parsed)
@@ -609,6 +613,12 @@ msg_parse_payload(sip_msg_t *msg, const char *payload)
     // Get Method and request for the following checks
     msg_get_reqresp(msg);
 
+    // CSeq
+    if (regexec(&calls.reg_cseq, payload, 2, pmatch, 0) == 0) {
+        sprintf(cseq, "%.*s", pmatch[1].rm_eo - pmatch[1].rm_so, payload + pmatch[1].rm_so);
+        msg->cseq = atoi(cseq);
+    }
+
     // X-Call-Id
     if (regexec(&calls.reg_xcallid, payload, 3, pmatch, 0) == 0) {
         msg_set_attribute(msg, SIP_ATTR_XCALLID, "%.*s", pmatch[2].rm_eo - pmatch[2].rm_so, payload + pmatch[2].rm_so);
@@ -894,6 +904,14 @@ sip_method_str(enum sip_methods method)
         return "BYE";
     case SIP_METHOD_ACK:
         return "ACK";
+    case SIP_METHOD_PRACK:
+        return "PRACK";
+    case SIP_METHOD_INFO:
+        return "INFO";
+    case SIP_METHOD_REFER:
+        return "REFER";
+    case SIP_METHOD_UPDATE:
+        return "UPDATE";
     case SIP_METHOD_SENTINEL:
         return "";
     }
