@@ -55,6 +55,10 @@ enum sip_methods {
     SIP_METHOD_CANCEL,
     SIP_METHOD_BYE,
     SIP_METHOD_ACK,
+    SIP_METHOD_PRACK,
+    SIP_METHOD_INFO,
+    SIP_METHOD_REFER,
+    SIP_METHOD_UPDATE,
     SIP_METHOD_SENTINEL,
 };
 
@@ -172,6 +176,7 @@ struct sip_call_list {
     int match_invert;
 
     //! Regexp for payload matching
+    regex_t reg_method;
     regex_t reg_callid;
     regex_t reg_xcallid;
     regex_t reg_response;
